1.14.0 “Professor D” — Rucio 1.2 documentation

# 1.14.0 “Professor D”

## General

### Features

- Authentication: Schema changes and upgrade file missing for ssh-identity changes #145
- Core & Internals: core: Schema change for database to add Partially Available(Imcomplete) to state column #104
- Core & Internals: core: dependencies update #187
- Deletion: Setting dataset/container state to PA and send message to AMI when first file gets deleted in Dataset #71
- Transfer Time To Complete Service #79
- Release management: Add missing migrate_repo files #148

### Enhancements

- Core & Internals: Resurrect method should remove expiration date of dataset if it is not deleted yet #116
- Core & Internals: schema.sql file should only contain table signatures, not ALTER table statements #204
- Core & Internals: Declare Datasets and parent Containers “Partially Available” when first replica gets removed from dataset #69
- Documentation: setup.py is needed for readthedocs #165
- Documentation: More work on documentation (reset) #86
- Release management: Provide Dockerfiles to create container #141
- Release management: Minor repository cleanups #205
- Rules: Option to “move” a rule in CLI #133

### Bugs

- Core & Internals: requested_at not properly filled in request_history table #74
- Deletion: Deletion: Reaper check for suspended/waiting for approval rules when it deletes dataset #142
- Life time model: Fix heartbeat in Atropos #122
- Life time model: Fix lifetime extension logic #196
- Fix bug in get_space in check_storage_space #168
- RSE Manager: rsemanager: _get_possible_protocols call raises exception while it should not #137
- RSE Manager: rsemanager: Wrong base path extraction #171
- RSE Manager: parse_pfn hotfix #298
- Release management: Fix current flake8 errors on master and next #155
- Release management: Fix flake8 command used in travis builds #158
- Rules: Injector needs to catch InsufficientAccountLimit #76
- Testing: configure_git.sh still points to gitlab #123
- Testing: Change prepare-commit-msg and remove RUCIO- JIRA template #174

## Clients

### Features

- Clients: clients: update module dependencies #185

### Enhancements

- Clients: clients: Add method to get md5 checksum from files #136

## WebUI

### Features

- WebUI: File download from WebUI #23

### Enhancements

- Accounting & Dumps: Add new updated_at fields to WebUI dumps page #192